
DROP TABLE IF EXISTS SCHEDULE;
CREATE TABLE SCHEDULE(
	ID					IDENTITY		NOT NULL,
	OBJECT_ID			BIGINT			NOT NULL,
	NAME				VARCHAR(255),
	DESCRIPTION			VARCHAR(255),
	TASK_ID				BIGINT			NOT NULL,
	STATUS				INT				NOT NULL,
	CREATE_DATE			TIMESTAMP,
	UPDATE_DATE			TIMESTAMP,
	VERSION_NO			DECIMAL,
	FOREIGN KEY(TASK_ID) REFERENCES TASK(ID),
	PRIMARY KEY(ID)
);

DROP TABLE IF EXISTS SCHEDULE_LOG;
CREATE TABLE SCHEDULE_LOG(
	ID					IDENTITY		NOT NULL,
	OBJECT_ID			BIGINT			NOT NULL,
	NAME				VARCHAR(255),
	DESCRIPTION			VARCHAR(255),
	TASK_ID				BIGINT			NOT NULL,
	LAST_STATUS			INT				NOT NULL,
	CREATE_DATE			TIMESTAMP,
	UPDATE_DATE			TIMESTAMP,
	VERSION_NO			DECIMAL,
	PRIMARY KEY(ID)
);

DROP TABLE IF EXISTS TRIGGER;
CREATE TABLE TRIGGER(
	ID					IDENTITY		NOT NULL PRIMARY KEY,	-- gK[ID(PK)
	OBJECT_ID			BIGINT			NOT NULL,				-- IuWFNgR[h
	NAME				VARCHAR(255),							-- gK[
	DESCRIPTION			VARCHAR(255),							-- 
	EXECUTE				BOOLEAN			NOT NULL DEFAULT 0,		-- s(s=true,~=false)
	EXEC_TYPE			CHAR(2)			NOT NULL,				-- TT = Timed, CT = Cron, DT = Delay, NT = NonDelay
	DELAY_TIME			BIGINT,									-- DT̒x			
	CRON_EXPRESSION		VARCHAR(255),							-- CTCRONR}h
	START_TIME			TIMESTAMP,								-- TT̊Jn\莞 (CTCRON_EXPRESSION)
	END_TIME			TIMESTAMP,								-- TT̏I\莞
	VERSION_NO			DECIMAL
);

DROP TABLE IF EXISTS TRIGGER_LOG;
CREATE TABLE TRIGGER_LOG(
	ID					IDENTITY		NOT NULL PRIMARY KEY,	-- gK[ID(PK)
	OBJECT_ID			BIGINT			NOT NULL,				-- IuWFNgR[h
	NAME				VARCHAR(255),							-- gK[
	DESCRIPTION			VARCHAR(255),							-- 
	EXECUTE				BOOLEAN			NOT NULL DEFAULT 0,		-- s(s=true,~=false)
	EXEC_TYPE			CHAR(2)			NOT NULL,				-- TT = Timed, CT = Cron, DT = Delay, NT = NonDelay
	DELAY_TIME			INT,									-- DT̒x			
	CRON_EXPRESSION		VARCHAR(255),							-- CTCRONR}h
	START_TIME			TIMESTAMP,								-- TT̊Jn\莞 (CTCRON_EXPRESSION)
	END_TIME			TIMESTAMP,								-- TT̏I\莞
	VERSION_NO			DECIMAL
);

DROP TABLE IF EXISTS CRON_EXPRESSION;
CREATE TABLE CRON_EXPRESSION(
	ID						IDENTITY				NOT NULL,				-- gK[ID(PK)
	OBJECT_ID				BIGINT				NOT NULL,				-- IuWFNgR[h
	START_TIME				TIMESTAMP			NOT NULL,				-- Jn\莞
	VESRION_NO				DECIMAL,
	FOREIGN KEY(ID) REFERENCES TRIGGER(ID),
	PRIMARY KEY(ID)
);

DROP TABLE IF EXISTS CRON_EXPRESSION_LOG;
CREATE TABLE CRON_EXPRESSION_LOG(
	ID							IDENTITY			NOT NULL,				-- gK[ID(PK)
	OBJECT_ID					BIGINT				NOT NULL,				-- IuWFNgR[h
	START_TIME					TIMESTAMP			NOT NULL,				-- Jn\莞
	VERSION_NO					DECIMAL,
	FOREIGN KEY(ID) REFERENCES TRIGGER_LOG(ID),
	PRIMARY KEY(ID)
);

DROP TABLE IF EXISTS THREAD_POOL;
CREATE TABLE THREAD_POOL(
	ID					IDENTITY			NOT NULL PRIMARY KEY,
	OBJECT_ID			BIGINT				NOT NULL,
	NAME				VARCHAR(255),
	DESCRIPTION			VARCHAR(255),
	THREAD_POOL_TYPE	INT					NOT NULL,
	THREAD_POOL_SIZE	INT,
	VERSION_NO			DECIMAL
);

DROP TABLE IF EXISTS THREAD_POOL_LOG;
CREATE TABLE THREAD_POOL_LOG(
	ID						IDENTITY		NOT NULL PRIMARY KEY,
	OBJECT_ID				BIGINT			NOT NULL,
	NAME					VARCHAR(255),
	DESCRIPTION				VARCHAR(255),
	THREAD_POOL_TYPE		INT				NOT NULL,
	THREAD_POOL_SIZE		INT,
	VERSION_NO				DECIMAL
);

DROP TABLE IF EXISTS TASK;
CREATE TABLE TASK(
	ID					IDENTITY			NOT NULL PRIMARY KEY,
	OBJECT_ID			BIGINT				NOT NULL,
	NAME				VARCHAR(255),
	DESCRIPTION			VARCHAR(255),
	THREAD_POOL_ID		BIGINT,
	THREAD_POOL_TYPE	INT,
	THREAD_POOL_SIZE	INT,
	TRIGGER_ID			BIGINT,
	EXECUTE				BOOLEAN,
	START_TASK			BOOLEAN,
	END_TASK			BOOLEAN,
	SHUTDOWN_TASK		BOOLEAN,
	VERSION_NO			DECIMAL,
	FOREIGN KEY(THREAD_POOL_ID) REFERENCES THREAD_POOL(ID),
	FOREIGN KEY(TRIGGER_ID) REFERENCES TRIGGER(ID)
);

DROP TABLE IF EXISTS TASK_LOG;
CREATE TABLE TASK_LOG(
	ID					IDENTITY				NOT NULL PRIMARY KEY,
	OBJECT_ID			BIGINT					NOT NULL,
	NAME				VARCHAR(255),
	DESCRIPTION			VARCHAR(255),
	THREAD_POOL_LOG_ID	BIGINT,
	THREAD_POOL_TYPE	INT,
	THREAD_POOL_SIZE	INT,
	TRIGGER_LOG_ID		BIGINT,
	EXECUTE				BOOLEAN,
	START_TASK			BOOLEAN,
	END_TASK			BOOLEAN,
	SHUTDOWN_TASK		BOOLEAN,
	VERSION_NO			DECIMAL,
	FOREIGN KEY(THREAD_POOL_LOG_ID) REFERENCES THREAD_POOL_LOG(ID),
	FOREIGN KEY(TRIGGER_LOG_ID) REFERENCES TRIGGER_LOG(ID)
);

